MouseMenuController subclass: #AreaController
	instanceVariableNames: ''
	classVariableNames: 'GraphYellowButtonMenu GraphYellowButtonMessages '
	poolDictionaries: ''
	category: 'ContGraph'!
AreaController comment:
' Trida ''AreaController'' vytvari ridici objekt pro zobrazovani
vysledku spojite simulace do grafu na obrazovku.

Promenne tridy:
GraphYellowButtonMenu <Menu>    - polozky menu, ktere se objevi po stisknuti
prostradniho tlacitka mysi
GraphYellowButtonMessages <Command>     - metody, ktere se maji provadet pri vyberu polozky z menu'!


!AreaController methodsFor: 'accessing'!

max: aNumber 
	"Nastavuje novou maximalni hodnotu zobrazitelnou v grafu."

	| log basic x num |
	num := aNumber.
	aNumber <= 0
		ifTrue: [view nMax: 0]
		ifFalse: 
			[log := num asDouble floorLog10.
			num < 1 ifTrue: [log := log - 1].
			basic := 10 ** log.
			x := 0.
			[x * basic < num & (num <= ((x := x + 1) * basic))] whileFalse.
			view nMax: (x * basic) asDouble]!

min: aNumber 
	"Nastavuje novou minimalni hodnotu zobrazitelnou v grafu."

	| log basic x num |
	num := aNumber abs.
	aNumber >= 0
		ifTrue: [view nMin: 0]
		ifFalse: 
			[log := num asDouble floorLog10.
			num < 1 ifTrue: [log := log - 1].
			basic := 10 ** log.
			x := 0.
			[x * basic < num & (num <= ((x := x + 1) * basic))] whileFalse.
			view nMin: (x * basic) negated asDouble]! !

!AreaController methodsFor: 'control'!

isControlActive
	"Vraci aktivitu controlleru."

	^super isControlActive & sensor blueButtonPressed not! !

!AreaController methodsFor: 'initialization'!

initialize
	"Inicializuje konkretni ridici objekt - jeho obrazova menu a promenne 
	supertridy."

	super initialize.
	self initializeYellowButtonMenu.!

initializeYellowButtonMenu
	"Vola metodu supertridy pro nastaveni noveho obrazoveho menu, 
	ktere se bude aktivovat pri stisknuti operacniho (prostredniho) 
	tlacitka mysi."

	self yellowButtonMenu: GraphYellowButtonMenu yellowButtonMessages: GraphYellowButtonMessages! !

!AreaController methodsFor: 'menu messages'!

displayNew
	"Prekresleni grafu."

	view displaySafe: [view clearInside; display]!

eTime
	"Nastaveni nove koncove hodnoty na ose x."

	| val |
	val := ''.
	[val = '']
		whileTrue: [val := FillInTheBlank request: 'Zadejte koncovy cas' initialAnswer: view eTime printString].
	val := val asNumber.
	val <= view sTime
		ifFalse: 
			[view eTime: val.
			view clearInside; display]!

maxV
	"Nastaveni nove maximalni hodnoty na ose y."

	| val |
	val := ''.
	[val = '']
		whileTrue: [val := FillInTheBlank request: 'Zadejte max. v y-ove ose' initialAnswer: view max printString].
	val := val asNumber.
	self max: val.
	view clearInside; display!

minV
	"Nastaveni nove minimalni hodnoty na ose y."

	| val |
	val := ''.
	[val = '']
		whileTrue: [val := FillInTheBlank request: 'Zadejte min. v y-ove ose' initialAnswer: view min printString].
	val := val asNumber.
	self min: val.
	view clearInside; display!

redButtonActivity
	"Provadena akce pri stisknuti (leveho) tlacitka mysi."

	| pom cBox |
	view topView isCollapsed
		ifFalse: 
			[cBox := view insetDisplayBox.
			pom := sensor cursorPoint.
			pom := pom - cBox topLeft.
			pom := view cas: pom.
			pom := view binFind: pom.
			pom size = 1 ifFalse: [(view topView subViews at: 2)
					displayNewValue: pom]]!

sTime
	"Nastaveni nove startovaci hodnoty na ose x."

	| val |
	val := ''.
	[val = '']
		whileTrue: [val := FillInTheBlank request: 'Zadejte zacatecni cas' initialAnswer: view sTime printString].
	val := val asNumber.
	val >= view eTime | (val < 0)
		ifFalse: 
			[view sTime: val.
			view clearInside; display]!

yellowButtonActivity
	"Rozliseni akci pri zmacknuti obrazoveho (praveho) tlacitka mysi pro 
	roztahnute okno a okno stahnute do ikony."

	view topView isCollapsed ifFalse: [^super yellowButtonActivity]! !
"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

AreaController class
	instanceVariableNames: ''!


!AreaController class methodsFor: 'class initialization'!

initialize
	"Inicializuje promenne tridy ridicich objektu inspektoru - obrazova 
	menu a akce s nimi spojene."

	GraphYellowButtonMessages := #(#maxV #minV #sTime #eTime #displayNew ).
	GraphYellowButtonMenu := PopUpMenu labels: 'Max v y-ove ose\Min v y-ove ose\Start cas\Konec cas\Prekresli' withCRs lines: #(4 )! !

AreaController initialize!


View subclass: #AreaGraphView
	instanceVariableNames: 'min max delka nMin nMax sTime eTime '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ContGraph'!
AreaGraphView comment:
' Trida ''AreaGraphView'' pomoci, ktere se vykresluje graf.

Promenne instanci:
min <Double>      - aktualni minimalni hodnota v grafu
max <Double>      - aktualni maximalni hodnota v grafu
delka <Integer>   - maximalni delka zobrazovamych popisu na ose y
nMin <Double>     - nova minimalni hodnota v grafu
nMax <Double>     - nova maximalni hodnota v grafu
sTime <Double>    - aktualni startovaci cas
eTime <Double>    - aktualni koncovy cas'!


!AreaGraphView methodsFor: 'accessing'!

binFind: aTime 
	"Vraci pole, v nemz je obsazena nejblizsi hodnota definovana v modelu, 
	odpovidajici poloze mysi v okne. Tato metoda prohledava serazene pole."

	| l r i cas pom |
	l := 1.
	r := model size.
	aTime > ((model at: r)
			at: 1) ifTrue: [^model at: r].
	i := l + r // 2.
	cas := aTime.
	r = 0
		ifTrue: [^#(0 )]
		ifFalse: 
			[[cas ~= ((model at: i)
					at: 1) & (r > l)]
				whileTrue: 
					[i := l + r // 2.
					cas < ((model at: i)
							at: 1)
						ifTrue: [r := i - 1]
						ifFalse: [l := i + 1]].
			r > l
				ifTrue: [^model at: i]
				ifFalse: 
					[pom := ((model at: l)
								at: 1)
								+ ((model at: l - 1)
										at: 1) / 2.
					cas < pom ifTrue: [^model at: l - 1].
					pom := ((model at: l + 1)
								at: 1)
								+ ((model at: l)
										at: 1) / 2.
					pom < cas
						ifTrue: [^model at: l + 1]
						ifFalse: [^model at: l]]]!

cas: aPoint 
	"Ziskani hodnoty casu ze souradnice mysi."

	| pom start cBox end |
	cBox := self insetDisplayBox.
	start := (delka * 6.5) rounded + 6.
	pom := aPoint x - start.
	end := cBox width - 20 - start.
	pom := pom / end.
	^eTime - sTime * pom + sTime!

endValue
	"Prekresleni grafu v koncove hodnote."

	self update: #endValue!

eTime
	"Vraci koncovou hodnotu casu."

	^eTime!

eTime: neweTime 
	"Nastavuje novou koncovou hodnotu casu."

	eTime := neweTime!

max
	"Vraci aktualni maximalni hodnotu souradnice grafu."

	^max!

min
	"Vraci aktualni minimalni hodnotu souradnice grafu."

	^min!

newValue: aArray 
	"Prirazeni noveho modelu a vykresleni zadanych hodnot do grafu."

	model := aArray.
	self update: #newValue!

nMax
	"Vraci novou maximalni hodnotu zobrazovanou v grafu."

	^nMax!

nMax: newnMax 
	"Nastavuje novou maximalni hodnotun zobrazovanou v grafu."

	nMax := newnMax!

nMin
	"Vraci novou minimalni hodnotu zobrazovanou v grafu."

	^nMin!

nMin: newnMin 
	"Nastavuje novou minimalni hodnotu zobrazovanou v grafu."

	nMin := newnMin!

sTime
	"Vraci pocatecni hodnotu casu."

	^sTime!

sTime: newsTime 
	"Nastavuje novou zacatecni hodnotu casu."

	sTime := newsTime! !

!AreaGraphView methodsFor: 'displaying'!

displayNewValue
	"Vykresleni novych hodnot do grafu."

	| cBox line form index1 pom bodu hM popMax popMin old pom1 out |
	self topView isCollapsed
		ifFalse: 
			[cBox := self insetDisplayBox.
			line := Line new.
			form := Form extent: 2 @ 2.
			form black.
			line form: form.
			model ~~ nil & (model size > 0)
				ifTrue: 
					[bodu := cBox height - 30 / (max + min abs).
					popMin := (delka * 6.5) rounded + 6.
					popMax := cBox width - 20 - popMin / (eTime - sTime).
					index1 := model size.
					out := ((model at: index1)
								at: 1)
								> eTime | (((model at: index1)
									at: 1)
									< sTime) | (((model at: index1 - 1)
									at: 1)
									> eTime) | (((model at: index1 - 1)
									at: 1)
									< sTime).
					out
						ifFalse: 
							[pom := (((model at: index1 - 1)
										at: 1)
										- sTime * popMax) rounded.
							pom1 := (((model at: index1)
										at: 1)
										- sTime * popMax) rounded.
							hM := (model at: index1 - 1) size + 1.
							[(hM := hM - 1) > 1]
								whileTrue: 
									[old := (model at: index1 - 1)
												at: hM.
									old <= 0
										ifTrue: [old := max + old abs]
										ifFalse: [old := max - old].
									line beginPoint: pom + popMin @ ((bodu * old) rounded + 15).
									out := line beginPoint x < popMin | (line beginPoint x > (cBox width - 20)) | (line beginPoint y < 15) | (line beginPoint y > (cBox height - 15)).
									old := (model at: index1)
												at: hM.
									old <= 0
										ifTrue: [old := max + old abs]
										ifFalse: [old := max - old].
									line endPoint: pom1 + popMin @ ((bodu * old) rounded + 15).
									out := line endPoint x < popMin | (line endPoint x > (cBox width - 20)) | (line endPoint y < 15) | (line endPoint y > (cBox height - 15)) | out.
									out ifFalse: [hM = 5
											ifTrue: [line
													displayOn: Display
													at: cBox topLeft
													clippingBox: cBox
													rule: Form over
													mask: Form darkGray]
											ifFalse: [hM = 4
													ifTrue: [line
															displayOn: Display
															at: cBox topLeft
															clippingBox: cBox
															rule: Form over
															mask: Form lightGray]
													ifFalse: [hM = 3
															ifTrue: [line
																	displayOn: Display
																	at: cBox topLeft
																	clippingBox: cBox
																	rule: Form over
																	mask: Form gray]
															ifFalse: [line
																	displayOn: Display
																	at: cBox topLeft
																	clippingBox: cBox
																	rule: Form over
																	mask: Form black]]]]]]]]!

displayView
	"Vykresleni grafu do okna, volane na zacatku a pri prekleslovani 
	grafu."

	| cBox line form par index index1 pom bodu hM popMax popMin old pom1 out |
	min := nMin. 
	max := nMax.
	model = nil | (model size = 0)
		ifTrue: 
			[min := -10.
			max := 10].
	cBox := self insetDisplayBox.	"urceni maximalni delky popisu y-ove osy"
	delka := sTime printString size.
	index1 := 0.
	[(index1 := index1 + 1) < 3]
		whileTrue: 
			[index1 = 1
				ifTrue: 
					[max ~~ 0
						ifTrue: 
							[pom := max asDouble floorLog10.
							max * (10 ** (pom abs)) < 1 ifTrue: [pom := pom - 1]].
					form := max.
					hM := max]
				ifFalse: 
					[min ~~ 0
						ifTrue: 
							[pom := min abs asDouble floorLog10.
							min abs * (10 ** (pom abs)) < 1 ifTrue: [pom := pom - 1]].
					form := min abs.
					hM := min].
			hM = 0
				ifFalse: 
					[form < 1
						ifTrue: [line := (form * (10 ** pom abs)) rounded]
						ifFalse: [line := (form * (10 ** pom negated)) rounded].
					index1 = 1
						ifTrue: [bodu := (cBox height - 30 / (max + min abs) * max) rounded]
						ifFalse: [bodu := cBox height - 30 - (cBox height - 30 / (max + min abs) * max) rounded].
					par := 1.
					bodu <= 20
						ifTrue: 
							[hM := 0.
							pom := Array new: 0]
						ifFalse: [bodu <= 40
								ifTrue: 
									[index := 0.
									par := 1]
								ifFalse: [bodu <= 80
										ifTrue: 
											[index := 1.
											line odd & (line ~~ 1) ifTrue: [par := 2]]
										ifFalse: [bodu <= 200
												ifTrue: 
													[index := 2.
													line = 2 ifTrue: [par := 2].
													line = 7 ifTrue: [par := 3]]
												ifFalse: 
													[index := 3.
													line = 2 ifTrue: [par := 3].
													line = 3 | (line = 4) | (line = 5) ifTrue: [par := 2]]]]].
					delka := hM printString size + par max: delka].
			hM = 0 ifFalse: [index = 0
					ifTrue: 
						[pom := Array new: 1.
						pom at: 1 put: hM]
					ifFalse: [index = 1
							ifTrue: 
								[pom := Array new: 2.
								pom at: 1 put: hM.
								pom at: 2 put: (hM / 2) asDouble]
							ifFalse: [index = 2
									ifTrue: [line = 1 | (line = 5)
											ifTrue: 
												[pom := Array new: 5.
												par := 5.
												form := 0.
												[(form := form + 1) < 6]
													whileTrue: 
														[pom at: form put: (hM * (par / 5)) asDouble.
														par := par - 1]]
											ifFalse: [line = 2 | (line = 4) | (line = 7) | (line = 8)
													ifTrue: 
														[pom := Array new: 4.
														par := 4.
														form := 0.
														[(form := form + 1) < 5]
															whileTrue: 
																[pom at: form put: (hM * (par / 4)) asDouble.
																par := par - 1]]
													ifFalse: 
														[pom := Array new: 3.
														par := 3.
														form := 0.
														[(form := form + 1) < 4]
															whileTrue: 
																[pom at: form put: (hM * (par / 3)) asDouble.
																par := par - 1]]]]
									ifFalse: 
										[line = 3 | (line = 6)
											ifTrue: 
												[pom := Array new: 6.
												par := 6.
												form := 0.
												[(form := form + 1) < 7]
													whileTrue: 
														[pom at: form put: (hM * (par / 6)) asDouble.
														par := par - 1]].
										line = 7
											ifTrue: 
												[pom := Array new: 7.
												par := 7.
												form := 0.
												[(form := form + 1) < 8]
													whileTrue: 
														[pom at: form put: (hM * (par / 7)) asDouble.
														par := par - 1]].
										line = 9
											ifTrue: 
												[pom := Array new: 9.
												par := 9.
												form := 0.
												[(form := form + 1) < 10]
													whileTrue: 
														[pom at: form put: (hM * (par / 9)) asDouble.
														par := par - 1]].
										line = 1 | (line = 5)
											ifTrue: 
												[pom := Array new: 10.
												par := 10.
												form := 0.
												[(form := form + 1) < 11]
													whileTrue: 
														[pom at: form put: (hM * (par / 10)) asDouble.
														par := par - 1]].
										line = 2 | (line = 4) | (line = 8)
											ifTrue: 
												[pom := Array new: 8.
												par := 8.
												form := 0.
												[(form := form + 1) < 9]
													whileTrue: 
														[pom at: form put: (hM * (par / 8)) asDouble.
														par := par - 1]]]]]].
			index1 = 1
				ifTrue: [popMax := pom]
				ifFalse: [popMin := pom]].	"vlastni tisk na obrazovku"
	line := Line new.
	par := sTime printString.
	par := par asParagraph textStyle: (TextStyle styleNamed: #icon).
	par
		displayOn: Display
		at: 1 @ ((cBox height - 30 / (max + min abs) * max) rounded + 16) + cBox topLeft
		clippingBox: cBox
		rule: Form over
		mask: Form black.
	line beginPoint: (delka * 6.5) rounded + 6 @ 5.
	line endPoint: (delka * 6.5) rounded + 6 @ (cBox height - 5).
	line
		displayOn: Display
		at: cBox topLeft
		clippingBox: cBox
		rule: Form over
		mask: Form black.
	line beginPoint: (delka * 6.5) rounded + 1 @ ((cBox height - 30 / (max + min abs) * max) rounded + 15).
	line endPoint: cBox width - 5 @ ((cBox height - 30 / (max + min abs) * max) rounded + 15).
	line
		displayOn: Display
		at: cBox topLeft
		clippingBox: cBox
		rule: Form over
		mask: Form black.
	max = 0
		ifFalse: 
			["tisk popisu"
			index := popMax size.
			index1 := -1.
			bodu := (cBox height - 30 / (max + min abs) * max) rounded.
			index ~~ 0 ifTrue: [bodu := (bodu / index) rounded].
			[(index1 := index1 + 1) < index]
				whileTrue: 
					[line beginPoint: (delka * 6.5) rounded + 4 @ (bodu * index1 + 15).
					line endPoint: (delka * 6.5) rounded + 8 @ (bodu * index1 + 15).
					line
						displayOn: Display
						at: cBox topLeft
						clippingBox: cBox
						rule: Form over
						mask: Form black.
					par := (popMax at: index1 + 1) printString.
					par := par asParagraph textStyle: (TextStyle styleNamed: #icon).
					par
						displayOn: Display
						at: 1 @ (bodu * index1 + 11) + cBox topLeft
						clippingBox: cBox
						rule: Form over
						mask: Form black]].
	min = 0
		ifFalse: 
			["tisk popisu"
			index := popMin size.
			index1 := 0.
			bodu := cBox height - 30 - (cBox height - 30 / (max + min abs) * max) rounded.
			index ~~ 0 ifTrue: [bodu := (bodu / index) rounded].
			[(index1 := index1 + 1) < (index + 1)]
				whileTrue: 
					[line beginPoint: (delka * 6.5) rounded + 4 @ (cBox height - (bodu * (index1 - 1) + 15)).
					line endPoint: (delka * 6.5) rounded + 8 @ (cBox height - (bodu * (index1 - 1) + 15)).
					line
						displayOn: Display
						at: cBox topLeft
						clippingBox: cBox
						rule: Form over
						mask: Form black.
					par := (popMin at: index1) printString.
					par := par asParagraph textStyle: (TextStyle styleNamed: #icon).
					par
						displayOn: Display
						at: 1 @ (cBox height - (bodu * (index1 - 1) + 19)) + cBox topLeft
						clippingBox: cBox
						rule: Form over
						mask: Form black]].	"tisk konce popis x-ove osy"
	par := 't' asParagraph textStyle: (TextStyle styleNamed: #icon).
	par
		displayOn: Display
		at: cBox width - 10 @ ((cBox height - 30 / (max + min abs) * max) rounded + 24) + cBox topLeft
		clippingBox: cBox
		rule: Form over
		mask: Form black.
	index := 11.
	popMin := (delka * 6.5) rounded + 6.
	popMax := cBox width - 20 - popMin / (eTime - sTime).
	bodu := cBox width - 20 - popMin.
	pom := (cBox height - 30 / (max + min abs) * max) rounded + 15.
	[(index := index - 1) > 0]
		whileTrue: 
			[par := sTime + (eTime - sTime * (index / 10)).
			index1 := (par - sTime * popMax) rounded.
			par := par asDouble printString.
			hM := par size.
			par := par asParagraph textStyle: (TextStyle styleNamed: #icon).
			par
				displayOn: Display
				at: index1 + popMin - (hM / 2 * 4.5) rounded @ (pom + 2) + cBox topLeft
				clippingBox: cBox
				rule: Form over
				mask: Form black.
			line beginPoint: index1 + popMin @ (pom - 1).
			line endPoint: index1 + popMin @ (pom + 1).
			line
				displayOn: Display
				at: cBox topLeft
				clippingBox: cBox
				rule: Form over
				mask: Form black.
			bodu < 400 ifTrue: [index := index - 1]].
	form := Form extent: 2 @ 2.
	form black.
	line form: form.
	model ~~ nil & (model size > 0)
		ifTrue: 
			[bodu := cBox height - 30 / (max + min abs).
			popMin := (delka * 6.5) rounded + 6.
			popMax := cBox width - 20 - popMin / (eTime - sTime).
			index := model size.
			index1 := 0.
			[(index1 := index1 + 1) < index]
				whileTrue: 
					[out := ((model at: index1)
								at: 1)
								> eTime | (((model at: index1)
									at: 1)
									< sTime) | (((model at: index1 + 1)
									at: 1)
									> eTime) | (((model at: index1 + 1)
									at: 1)
									< sTime).
					out
						ifFalse: 
							[pom := (((model at: index1)
										at: 1)
										- sTime * popMax) rounded.
							pom1 := (((model at: index1 + 1)
										at: 1)
										- sTime * popMax) rounded.
							hM := (model at: index1) size + 1.
							[(hM := hM - 1) > 1]
								whileTrue: 
									[old := (model at: index1)
												at: hM.
									old <= 0
										ifTrue: [old := max + old abs]
										ifFalse: [old := max - old].
									line beginPoint: pom + popMin @ ((bodu * old) rounded + 15).
									out := line beginPoint x < popMin | (line beginPoint x > (cBox width - 20)) | (line beginPoint y < 15) | (line beginPoint y > (cBox height - 15)).
									old := (model at: index1 + 1)
												at: hM.
									old <= 0
										ifTrue: [old := max + old abs]
										ifFalse: [old := max - old].
									line endPoint: pom1 + popMin @ ((bodu * old) rounded + 15).
									out := line endPoint x < popMin | (line endPoint x > (cBox width - 20)) | (line endPoint y < 15) | (line endPoint y > (cBox height - 15)) | out.
									out not ifTrue: [hM = 5
											ifTrue: [line
													displayOn: Display
													at: cBox topLeft
													clippingBox: cBox
													rule: Form over
													mask: Form darkGray]
											ifFalse: [hM = 4
													ifTrue: [line
															displayOn: Display
															at: cBox topLeft
															clippingBox: cBox
															rule: Form over
															mask: Form lightGray]
													ifFalse: [hM = 3
															ifTrue: [line
																	displayOn: Display
																	at: cBox topLeft
																	clippingBox: cBox
																	rule: Form over
																	mask: Form gray]
															ifFalse: [line
																	displayOn: Display
																	at: cBox topLeft
																	clippingBox: cBox
																	rule: Form over
																	mask: Form black]]]]]]]]! !

!AreaGraphView methodsFor: 'initialization'!

initializeValue: newstartTime end: newendTime model: aModel 
	"Inicializace instancnich promennych."

	nMin := 0.
	nMax := 0.
	sTime := newstartTime.
	eTime := newendTime.
	self model: aModel!

start: newstartTime end: newendTime text: aText 
	"Inicializace velikosti intervalu vypisu promennych."

	sTime := newstartTime.
	eTime := newendTime.
	self clearInside.
	self display.
	(self topView subViews at: 2)
		initializeValue: aText! !

!AreaGraphView methodsFor: 'updating'!

update: aParameter 
	"Zapisovani nove hodnoty do grafu."

	superView = nil ifFalse: [self topView isCollapsed
			ifFalse: 
				[aParameter == #newValue ifTrue: [^self topView controller newValue].
				aParameter == #endValue ifTrue: [^self topView controller endValue]]]! !
"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

AreaGraphView class
	instanceVariableNames: ''!


!AreaGraphView class methodsFor: 'instance creation'!

open: nameNew model: aModel start: newstartTime end: newendTime 
	"Otevreni noveho okna grafu."

	| pom topView pom1 |
	pom := self new
				initializeValue: newstartTime
				end: newendTime
				model: aModel.
	pom1 := AreaValueView new initializeValue: #().
	pom1 insideColor: Form white.
	pom controller: (AreaController new).
	pom insideColor: Form white.
	topView := StandardSystemView
				model: nil
				label: 'Graph:  ' , nameNew
				minimumSize: 300 @ 200.
	topView
		addSubView: pom
		in: (0 @ 0 extent: 0.85 @ 1)
		borderWidth: 1.
	topView
		addSubView: pom1
		in: (0.85 @ 0 extent: 1 @ 1)
		borderWidth: 0.
	topView borderWidth: 2.
	topView controller: (AreaGraphController  new).	"pak udelat naraz v inicializaci systemu"
	topView controller openNoTerminate.
	^pom! !

View subclass: #AreaValueView
	instanceVariableNames: 'input value '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ContGraph'!
AreaValueView comment:
' Trida ''AreaValueView'' vytvari cast okna grafu, ve kterem je
zobrazovana informace o jednotlivych prubezich v grafu a hodnoty
prubehu v grafu pri stisku leveho tlacitka mysi.

Promenne instanci:
input <Array>     - pole jmen prubehu grafu
value <Array>     - pole hodnot, ve kterem jsou ulozeny hodnoty,
odpovidajici poloze mysi pri stisku leveho tlacitka'!


!AreaValueView methodsFor: 'displaying'!

displayNewValue: aValue 
	"Zobrazeni novych hodnot do popisu grafu."

	| cBox par index vel posun |
	self topView isCollapsed
		ifFalse: 
			[cBox := self insetDisplayBox.
			index := value size + 1.
			vel := cBox height.
			vel := (vel / (index - 1)) rounded.
			posun := 0.
			[(index := index - 1) > 0]
				whileTrue: 
					[par := value at: index.
					par := par printString.
					par := par asParagraph.
					par
						displayOn: Display
						at: 1 @ (posun + 25) + cBox topLeft
						clippingBox: cBox
						rule: Form over
						mask: Form white.
					par := aValue at: index.
					par := par printString.
					par := par asParagraph.
					par
						displayOn: Display
						at: 1 @ (posun + 25) + cBox topLeft
						clippingBox: cBox
						rule: Form over
						mask: Form black.
					posun := posun + vel].
			value := aValue]!

displayView
	"Zobrazeni popisu grafu."

	| cBox line form par index vel posun |
	cBox := self insetDisplayBox.
	line := Line new.
	form := Form extent: 2 @ 2.
	form black.
	line form: form.
	index := input size + 1.
	vel := cBox height.
	vel := (vel / index) rounded.
	posun := 0.
	[(index := index - 1) > 0]
		whileTrue: 
			[line beginPoint: 1 @ (posun + 2).
			line endPoint: 15 @ (posun + 2).
			index = 4
				ifTrue: [line
						displayOn: Display
						at: cBox topLeft
						clippingBox: cBox
						rule: Form over
						mask: Form darkGray]
				ifFalse: [index = 3
						ifTrue: [line
								displayOn: Display
								at: cBox topLeft
								clippingBox: cBox
								rule: Form over
								mask: Form lightGray]
						ifFalse: [index = 2
								ifTrue: [line
										displayOn: Display
										at: cBox topLeft
										clippingBox: cBox
										rule: Form over
										mask: Form gray]
								ifFalse: [line
										displayOn: Display
										at: cBox topLeft
										clippingBox: cBox
										rule: Form over
										mask: Form black]]].
			par := input at: index.
			par := par asParagraph textStyle: (TextStyle styleNamed: #icon).
			par
				displayOn: Display
				at: 1 @ (posun + 6) + cBox topLeft
				clippingBox: cBox
				rule: Form over
				mask: Form black.
			par := value at: index + 1.
			par := par printString.
			par := par asParagraph textStyle: (TextStyle styleNamed: #icon).
			par
				displayOn: Display
				at: 1 @ (posun + 25) + cBox topLeft
				clippingBox: cBox
				rule: Form over
				mask: Form black.
			posun := posun + vel].
	value size = 1
		ifFalse: 
			[par := 'cas' asParagraph textStyle: (TextStyle styleNamed: #icon).
			par
				displayOn: Display
				at: 1 @ (posun + 6) + cBox topLeft
				clippingBox: cBox
				rule: Form over
				mask: Form black.
			par := value at: 1.
			par := par printString.
			par := par asParagraph textStyle: (TextStyle styleNamed: #icon).
			par
				displayOn: Display
				at: 1 @ (posun + 25) + cBox topLeft
				clippingBox: cBox
				rule: Form over
				mask: Form black]! !

!AreaValueView methodsFor: 'initialization'!

initializeValue: aText 
	"Inicializace instancnich promennych."

	input := aText.
	value := Array new: input size + 1.
	value atAllPut: 0.
	self displayView! !

StandardSystemController subclass: #AreaGraphController
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ContGraph'!
AreaGraphController comment:
' Trida ''AreaGraphController'' vytvari controller pro subView
vysledku spojite simulace v grafu vypisovanem na obrazovce.'!


!AreaGraphController methodsFor: 'control'!

endValue
	"Konecne prekresleni grafu."

	view topView isCollapsed ifFalse: [view displaySafe: [(view subViews at: 1) clearInside; display]]!

newValue
	"Zapsani nove hodnoty do grafu."

	view topView isCollapsed ifFalse: [view displaySafe: [(view subViews at: 1) displayNewValue]]! !