Object subclass: #BasicInput
	instanceVariableNames: 'timeStart '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ContSimHelpClass'!
BasicInput comment:
' Trida ''BasicInput'' je bazovou tridou pro vsechny vstupni bloky
spojite simulace.

Promenne instanci:
timeStart <Double>      - cas zacatku pocitani vstupu'!


!BasicInput methodsFor: 'accessing'!

getName
	"Vraci jmeno vstupniho bloku."

	^'vstup'!

timeStart
	"Vraci hodnotu casu, od ktereho zacina pocitani vstupu."

	^timeStart! !

!BasicInput methodsFor: 'initialization'!

initialize: startTime 
	"Inicializuje vstupni blok."

	| sl |
	startTime < 0 ifTrue: [MySimulation error: 'Cas zacatku vstupni hodhoty je zaporny.'].
	timeStart := startTime asDouble.
	startTime > 0
		ifTrue: 
			[sl := SimProcess new: [].
			sl activateAt: startTime]! !
"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

BasicInput class
	instanceVariableNames: ''!


!BasicInput class methodsFor: 'instance creation'!

new: startTime 
	"Vytvari a inicializuje vstupni blok."

	^super new initialize: startTime! !

BasicInput subclass: #BasicInputStep
	instanceVariableNames: 'step '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ContSimHelpClass'!
BasicInputStep comment:
' Trida ''BasicInputStep'' je bazovou tridou pro vstupni bloky se skrokovou
promennou.

Promenne instanci:
step <Double>      - krok v y-ove ose'!


!BasicInputStep methodsFor: 'accessing'!

step
	"Vraci hodnotu skoku."

	^step! !

!BasicInputStep methodsFor: 'initialization'!

initialize: startTime step: newStep 
	"Inicializuje vstupni blok na skok hodnoty v ose y."

	step := newStep asDouble.
	super initialize: startTime! !
"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

BasicInputStep class
	instanceVariableNames: ''!


!BasicInputStep class methodsFor: 'instance creation'!

new: startTime 
	"Vytvari a inicializuje vstupni blok na jednotkovy skok v ose y."

	^super new initialize: startTime step: 1!

new: startTime step: newStep 
	"Vytvari a inicializuje vstupni blok."

	^super new initialize: startTime step: newStep! !

BasicInputStep subclass: #BasicInputPulse
	instanceVariableNames: 'duration '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ContSimHelpClass'!
BasicInputPulse comment:
' Trida ''BasicInputPulse'' je bazovou tridou pro vstupni bloky s impulsni
charakteristikou.

Promenne instanci:
duration <Double>      - delka impulsu'!


!BasicInputPulse methodsFor: 'accessing'!

duration
	"Vraci hodnotu delky trvani impulsu."

	^duration! !

!BasicInputPulse methodsFor: 'initialization'!

initialize: startTime step: newStep duration: newDuration 
	"Inicializuje vstupni blok na impuls."

	super initialize: startTime step: newStep.
	newDuration <= 0 ifTrue: [MySimulation error: 'Delka trvani impulsu je <= 0.'].
	duration := newDuration asDouble! !
"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

BasicInputPulse class
	instanceVariableNames: ''!


!BasicInputPulse class methodsFor: 'instance creation'!

new: startTime 
	"Vytvari a inicializuje vstupni blok na jednotkovy impuls."

	^super new
		initialize: startTime
		step: 1
		duration: 1!

new: startTime step: newStep duration: newDuration 
	"Vytvari a inicializuje vstupni blok na impuls."

	^super new
		initialize: startTime
		step: newStep
		duration: newDuration! !

Object subclass: #BasicMatFunOne
	instanceVariableNames: 'oneInput eval '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ContSimHelpClass'!
BasicMatFunOne comment:
' Trida ''BasicMatFunOne'' je bazovou tridou pro vsechny
matematicke bloky, jak jednovstupove, tak i vicevstupove.

Promenne instanci:
oneInput <Double, Pointer>       - bud konstantni hodnota, nebo odkaz na blok
eval <Boolean>                  - priznak vyhodnocovani bloku'!


!BasicMatFunOne methodsFor: 'accessing'!

getName
	"Vraci jmeno bloku."

	^'Matematicka funkce'!

oneInput
	"Vraci odkaz na vstupni blok."

	^oneInput! !

!BasicMatFunOne methodsFor: 'initialization'!

initialize
	"Inicializuje spolecne promenne."

	oneInput := ''.
	eval := false! !

!BasicMatFunOne methodsFor: 'task language'!

= newInput 
	"Nastavuje odkaz na vstupni blok."

	oneInput := newInput! !
"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

BasicMatFunOne class
	instanceVariableNames: ''!


!BasicMatFunOne class methodsFor: 'instance creation'!

new
	"Vytvari a inicializuje matematicky blok."

	^super new initialize! !

BasicMatFunOne subclass: #BasicMatFunTwo
	instanceVariableNames: 'twoInput '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ContSimHelpClass'!
BasicMatFunTwo comment:
' Trida ''BasicMatFunTwo'' je bazovou tridou pro matematicke bloky
se dvema vstupy.

Promenne instanci:
twoInput <Double, Pointer>       - bud konstantni hodnota, nebo odkaz na blok'!


!BasicMatFunTwo methodsFor: 'accessing'!

twoInput
	"Vraci odkaz na vstupni blok."

	^twoInput! !

!BasicMatFunTwo methodsFor: 'initialization'!

initialize
	"Inicializuje spolecne promenne."

	twoInput := ''.
	oneInput := ''.
	eval := false! !

Object subclass: #Const
	instanceVariableNames: 'value '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ContSimHelpClass'!
Const comment:
' Trida ''Graph'' predstavuje konstantni hodnotu. Je pouzita 
pri grafovem zadavani spojite simulace.

Promenne instanci:
value <Double>       - hodnota konstanty'!


!Const methodsFor: 'accessing'!

getName
	"Vraci jmeno bloku."

	^'Konstanta'! !

!Const methodsFor: 'task language'!

value
	"Vraci hodnotu konstanty."
	^value! !

!Const methodsFor: 'initialize'!

initialize: newValue 
	"Inicializuje hodnotu konstanty."
	value _ newValue! !
"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

Const class
	instanceVariableNames: ''!


!Const class methodsFor: 'instance creation'!

new: newValue 
	"Vytvari a inicializuje konstantu."
	^super new initialize: newValue! !

Object subclass: #ZaklSpoj
	instanceVariableNames: 'input name '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ContSimHelpClass'!
ZaklSpoj comment:
' Trida ''ZaklSpoj'' je bazovou tridou pro vsechny funkcni bloky
spojite simulace.

Promenne instanci:
input <Pointer>       - odkaz na vstupni blok
name <String>         - jmeno funkcniho bloku'!


!ZaklSpoj methodsFor: 'accessing'!

getName
	"Vraci jmeno vstupniho bloku."

	^name!

input
	"Vraci odkaz na vstupni blok."

	^input!

setName: newName 
	"Nastavuje jmeno vstupniho bloku."

	name := newName! !

!ZaklSpoj methodsFor: 'initialization'!

initialize: newName 
	"Inicializuje spolecne promenne."

	name := newName.
	input := ''! !

!ZaklSpoj methodsFor: 'task language'!

= newInput 
	"Nastavuje odkaz na vstupni blok."

	input := newInput! !
"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

ZaklSpoj class
	instanceVariableNames: ''!


!ZaklSpoj class methodsFor: 'instance creation'!

new: newName 
	"Vytvari novou instanci bloku spojite simulace."

	^super new initialize: newName! !

ZaklSpoj subclass: #SpojNestav
	instanceVariableNames: 'low high tgAlpha eval '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ContSimHelpClass'!
SpojNestav comment:
' Trida ''SpojNestav'' je bazovou tridou pro vsechny funkcni nestavove bloky
spojite simulace.

Promenne instanci:
low <Double>      - parametr funkcniho bloku
high <Double>     - parametr funkcniho bloku
tgAlpha <Double>  - parametr funkcniho bloku
eval <Boolean>    - priznak vyhodnocovani bloku'!


!SpojNestav methodsFor: 'accessing'!

high
	"Vraci vyssi mez."

	^high!

low
	"Vraci nizsi mez."

	^low!

tgAlpha
	"Vraci parametr 'tgAlpha'."

	^tgAlpha! !

!SpojNestav methodsFor: 'initialization'!

initialize: newName low: newLow high: newHigh tgAlpha: newTgAlpha 
	"Inicializuje spolecne promenne pro nestavove bloky."

	super initialize: newName.
	low := newLow asDouble.
	high := newHigh asDouble.
	tgAlpha := newTgAlpha asDouble.
	eval := false! !
"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SpojNestav class
	instanceVariableNames: ''!


!SpojNestav class methodsFor: 'instance creation'!

new: newName low: newLow high: newHigh tgAlpha: newTgAlpha 
	"Vytvari novou instanci nestavoveho bloku spojite simulace."

	^super new
		initialize: newName
		low: newLow
		high: newHigh
		tgAlpha: newTgAlpha! !

ZaklSpoj subclass: #SpojStav
	instanceVariableNames: 'st stl low high valueOK '
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ContSimHelpClass'!
SpojStav comment:
' Trida ''SpojStav'' je bazovou tridou pro vsechny funkcni stavove bloky
spojite simulace.

Promenne instanci:
st <Double>       - aktualni hodnota stavoveho bloku
stl <Double>      - hodnota stavoveho bloku stara
low <Double>      - parametr funkcniho bloku
high <Double>     - parametr funkcniho bloku
valueOk <Boolean> - pomocny priznak'!


!SpojStav methodsFor: 'accessing'!

high
	"Vraci vyssi mez."

	^high!

low
	"Vraci nizsi mez."

	^low!

lTon
	"Obnova stavu bloku."

	st := stl.
	valueOK := false!

nTol
	"Uschova stavu bloku."

	stl := st!

st
	"Vraci stav stavoveho bloku."

	^st!

st: newSt 
	"Nastavuje stav stavoveho bloku."

	st := newSt asDouble!

stl
	"Vraci stav stavoveho bloku."

	^stl!

stl: newStl 
	"Nastavuje stav stavoveho bloku."

	stl := newStl asDouble! !

!SpojStav methodsFor: 'initialization'!

clear
	"Inicializuje hodnotu promenne 'valueOK'."

	valueOK := false!

initialize: newName low: newLow high: newHigh 
	"Inicializuje spolecne promenne pro stavove bloky."

	super initialize: newName.
	low := newLow asDouble.
	high := newHigh asDouble.
	st := 0.
	stl := 0.
	valueOK := false!

initVal: newValue 
	"Inicializace hodnoty pro stavove bloky."

	st := newValue asDouble.
	valueOK := false! !

!SpojStav methodsFor: 'task language'!

setValue: newValue 
	"Nastavuje aktualni hodnotu stavoveho bloku."

	st := newValue asDouble.
	valueOK := false!

value
	"Vraci aktualni hodnotu stavoveho bloku."

	^st! !
"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

SpojStav class
	instanceVariableNames: ''!


!SpojStav class methodsFor: 'instance creation'!

new
	"Vytvari novou instanci stavoveho bloku."

	^MySimulation active statusNew: super new! !